package at.ac.uibk.gitsearch.domain;

import java.text.ParseException;
import org.codeability.sharing.plugins.api.search.util.ExerciseId;
import org.junit.Assert;
import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.params.ParameterizedTest;
import org.junit.jupiter.params.provider.ValueSource;

public class ExerciseIdTest {

    @ParameterizedTest
    @ValueSource(strings = { "3", "3:path", "3:path1/path2" })
    public void parseVariousIds(String externalRepresentation) throws ParseException {
        Assert.assertEquals(externalRepresentation, ExerciseId.fromString(externalRepresentation).toString());
    }

    @Test
    public void parseIdsWithTrailingSlashes() throws ParseException {
        Assert.assertEquals("30:abc", ExerciseId.fromString("30:/abc").toString());
        Assert.assertEquals("30:abc", ExerciseId.fromString("30://abc").toString());
        Assert.assertEquals("30", ExerciseId.fromString("30://").toString());
        Assert.assertEquals("30:abc/def", ExerciseId.fromString("30:/abc/def").toString());
    }

    @ParameterizedTest
    @ValueSource(strings = { "=", ":path", "3x2", "3x2:/asd", "asdf=asd:30" })
    public void parseCorruptIds(String corruptIds) throws ParseException {
        Assertions.assertThrows(ParseException.class, () -> ExerciseId.fromString(corruptIds));
    }
}
